<?php

class MVB_recent_products
{
	/**
	 * The modules settings
	 *
	 * @access public
	 * @param none
	 * @return array settings
	 */

	public static function settings()
	{
		return array(
			'title'           =>      __('Recent shop items', 'mvb'),
			'description'     =>      __('Recent items from woocommerce', 'mvb'),
			'identifier'      =>      __CLASS__,
			'icon'            =>      'appbar.newspaper.png',
			'section'         =>      'content',
			'color'           =>      'gray'
		);
	}//end settings()

	/**
	 * The shortcodes attributes with the field options
	 *
	 * @access private
	 * @param array $atts
	 * @return shortcode output
	 */

	public static function fields()
	{
		global $mvb_metro_factory;

		$the_fields = array(
			'main_title' => array(
				'type'      =>      'text',
				'label'     =>      __('Title', 'mvb'),
				'col_span'  =>      'lbl_half'
			),
			'icon_title' => array(
				'type'      =>      'icon',
				'label'     =>      __('Icon', 'mvb'),
				'col_span'  =>      'lbl_half'
			),

			'categories' => array(
				'type'      =>      'select_multi',
				'title'     =>      __('Select category', 'mvb'),
				'label'     =>      __('Categories', 'mvb'),
				'callback'  =>      'mvb_get_select_options_multi',
				'options'   =>      'product_cat',
			),

			'show_title' => array(
				'type'      =>      'select',
				'label'     =>      __('Display item title', 'mvb'),
				'default'   =>      1,
				'options'   =>      mvb_yes_no(),
				'col_span'  =>      'lbl_third'
			),
			'show_meta' => array(
				'type'      =>      'select',
				'label'     =>      __('Display the description', 'mvb'),
				'default'   =>      1,
				'options'   =>      mvb_yes_no(),
				'col_span'  =>      'lbl_third'
			),
			'number_items' => array(
				'type'      =>      'text',
				'label'     =>      __('How many items to display', 'mvb'),
				'default'   =>      '10',
				'col_span'  =>      'lbl_third'
			),

			'separator-effects' => array('type'     =>  'separator'),

			'thumb_size' => array(
				'type'      =>      'select',
				'label'     =>      __('Thumbnail size', 'mvb'),
				'help'      =>      __('Select thumbnail size for bocks', 'mvb'),
				'default'   =>      'metro',
				'options'   =>      crum_thumbnail_style(),
				'col_span'  =>      'lbl_half'
			),

			'effects' => array(
				'type'      =>      'select',
				'label'     =>      __('Appear effects', 'mvb'),
				'help'      =>      __('Select one of appear effects for block', 'mvb'),
				'default'   =>      0,
				'options'   =>      crum_appear_effects(),
				'col_span'  =>      'lbl_half'
			),

			'css' => array(
				'type'      =>      'text',
				'label'     =>      __('Additional CSS classes', 'mvb'),
				'help'      =>      __('Separated by space', 'mvb'),
				'col_span'  =>      'lbl_half'
			),
		);

		return $the_fields;
	}//end fields();

	/**
	 * The private code for the shortcode. used in the custom editor
	 *
	 * @access public
	 * @param array $atts
	 * @return shortcode output
	 */

	public static function admin_render( $atts = array(), $content = '' )
	{
		global $mvb_metro_factory;
		global $mvb_metro_form_builder;
		$form_fields = self::fields();

		$load = shortcode_atts( $mvb_metro_factory->defaults($form_fields), $atts );
		$load['content'] = $content;

		if( $mvb_metro_factory->show_pill_sc OR $mvb_metro_factory->show_pill_sc_column )
		{
			if( method_exists(__CLASS__, 'the_pill') )
			{
				return self::the_pill($load, self::settings());
			}
			else
			{
				return $mvb_metro_factory->the_pill($load, self::settings());
			}

		}
		else
		{
			$load['form_fields_html'] = $mvb_metro_form_builder->build_form($form_fields, $load);
			$load['settings'] = self::settings();
			$load['form_fields'] = $form_fields;
			$load['module_action'] = $mvb_metro_factory->module_action;
			$load['content'] = $content;

			return $mvb_metro_factory->_load_view('html/private/mvb_form.php', $load);
		}//endif

	}//end admin_render();

	/**
	 * The public code for the shortcode
	 *
	 * @access public
	 * @param array $atts
	 * @return shortcode output
	 */
	public static function render( $atts )
	{
		global $mvb_metro_factory;

		$load = $atts;

		$_sh_js = array(
			'depends' => array('jquery'),
			'js' => array(
				'isotope-js' => get_template_directory_uri() . '/library/js/isotope.min.js'
			)
		);
		$mvb_metro_factory->queue_scripts($_sh_js, __CLASS__);


		return $mvb_metro_factory->_load_view('html/public/mvb_recent_products.php', $load);
	}//end render();
}